@@ -139,7 +139,7 @@ place_in_center (MetaWindow *window,
   int center_x, center_y;
   const MetaMonitorInfo *xi;
 
-  xi = meta_screen_get_current_monitor (window->screen);
+  xi = meta_screen_get_current_monitor_info (window->screen);
   center_x = *new_x + xi->rect.width / 2;
   center_y = *new_y + xi->rect.height / 2;
 
@@ -177,7 +177,7 @@ find_next_cascade (MetaWindow *window,
   int window_width, window_height;
   int cascade_stage;
   MetaRectangle work_area;
-  const MetaMonitorInfo* current;
+  int current;
   
   sorted = g_list_copy (windows);
   sorted = g_list_sort (sorted, northwestcmp);
@@ -203,7 +203,7 @@ find_next_cascade (MetaWindow *window,
    */
 
   current = meta_screen_get_current_monitor (window->screen);
-  meta_window_get_work_area_for_monitor (window, current->number, &work_area);
+  meta_window_get_work_area_for_monitor (window, current, &work_area);
 
   cascade_x = MAX (0, work_area.x);
   cascade_y = MAX (0, work_area.y);
@@ -881,7 +881,7 @@ meta_window_place (MetaWindow        *window,
       int w, h;
 
       /* Warning, this function is a round trip! */
-      xi = meta_screen_get_current_monitor (window->screen);
+      xi = meta_screen_get_current_monitor_info (window->screen);
 
       w = xi->rect.width;
       h = xi->rect.height;
@@ -928,7 +928,7 @@ meta_window_place (MetaWindow        *window,
   }
 
   /* Warning, this is a round trip! */
-  xi = meta_screen_get_current_monitor (window->screen);
+  xi = meta_screen_get_current_monitor_info (window->screen);
   
   /* "Origin" placement algorithm */
   x = xi->rect.x;
